/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:STRING,UINT,STRING,POINTER (../gupnp-av/libgupnp-av/gupnp-av-marshal.list:1) */
extern
void gupnp_av_marshal_BOOLEAN__STRING_UINT_STRING_POINTER (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);


G_END_DECLS
